@@ -7,7 +7,7 @@ use File::Spec::Functions qw/catfile rel2abs/;
 use Module::CPANfile;
 use version;
 
-our $VERSION = "0.06";
+our $VERSION = "0.07";
 
 sub import {
   my $class = shift;
@@ -64,6 +64,26 @@ sub import {
           $params{META_MERGE}{dynamic_config} = 0;
       }
 
+      # recommends, suggests, conflicts
+      my $requires_2_0;
+      for my $type (qw/recommends suggests conflicts/) {
+          for my $phase (qw/configure build test runtime develop/) {
+              my %tmp = %{$params{META_MERGE}{prereqs}{$phase} || {}};
+              _merge(
+                  \%tmp,
+                  _get($prereqs, $phase, $type),
+                  $type,
+              );
+              if ($tmp{$type}) {
+                  $params{META_MERGE}{prereqs}{$phase} = \%tmp;
+                  $requires_2_0 = 1;
+              }
+          }
+      }
+      if ($requires_2_0) { # for better recommends support
+          $params{META_MERGE}{"meta-spec"} ||= {version => 2};
+      }
+
       # XXX: better to use also META_MERGE when applicable?
 
       # As a small bonus, remove params that the installed version
@@ -209,7 +229,7 @@ to true explicitly (via META_ADD/META_MERGE).
 
 =head1 FOR MODULE AUTHORS
 
-Thoguh the minimum version requirement of ExtUtils::MakeMaker is
+Though the minimum version requirement of ExtUtils::MakeMaker is
 arbitrary set to 6.17 (the one bundled in Perl 5.8.1), you need
 at least EUMM 6.52 (with CONFIGURE_REQUIRES support) when you
 release a distribution.
